@@ -36,8 +36,8 @@ class Bar(Graph):
         bars = self.svg.node(serie_node['plot'], class_="bars")
         view_values = map(view, values)
         for i, ((x, y), (X, Y)) in enumerate(view_values):
-            tag = '%d_%d' % (serie.index, i)
             # x and y are left range coords and X, Y right ones
+            val = self.format(values[i][1][1])
             if self._horizontal:
                 x, y, X, Y = Y, X, y, x
             width = X - x
@@ -73,20 +73,28 @@ class Bar(Graph):
                 ry=self.rounded_bars * 1,
                 width=bar_inner_width,
                 height=height,
-                id="active-%s" % tag,
-                class_='rect reactive')
+                class_='rect reactive tooltip-trigger')
+            self.svg.node(bar, 'desc', class_="values").text = val
+            tooltip_positions = map(
+                str, (x + bar_inner_width / 2., y + height / 2.))
+            self.svg.node(bar, 'desc',
+                          class_="x centered"
+            ).text = tooltip_positions[int(self._horizontal)]
+            self.svg.node(bar, 'desc',
+                          class_="y centered"
+            ).text = tooltip_positions[int(not self._horizontal)]
             if self._horizontal:
-                x += .3 * self.values_font_size
+                x += .3 * self.value_font_size
                 y += height / 2
             else:
-                y += height / 2 + .3 * self.values_font_size
-            self.svg.transposable_node(
-                serie_node['overlay'], 'text',
-                x=x + bar_inner_width / 2,
-                y=y - shift,
-                id="reactive-%s" % tag,
-                class_='reactive-text'
-            ).text = str(values[i][1][1])
+                y += height / 2 + .3 * self.value_font_size
+            if self.print_values:
+                self.svg.transposable_node(
+                    serie_node['text_overlay'], 'text',
+                    class_='centered',
+                    x=x + bar_inner_width / 2,
+                    y=y - shift
+                ).text = val if self.print_zeroes or val != '0' else ''
         return stack_vals
 
     def _compute(self):
@@ -101,7 +109,7 @@ class Bar(Graph):
         self._x_ranges = zip(x_pos, x_pos[1:])
         self._x_labels = self.x_labels and zip(self.x_labels, [
             sum(x_range) / 2. for x_range in self._x_ranges])
-        self._y_labels = zip(map(str, y_pos), y_pos)
+        self._y_labels = zip(map(self.format, y_pos), y_pos)
 
     def _plot(self):
         for serie in self.series:
