@@ -25,7 +25,7 @@ class Line(Graph):
     """Line graph"""
 
     def _get_value(self, values, i):
-        return str(values[i][1])
+        return self.format(values[i][1])
 
     @cached_property
     def _values(self):
@@ -44,19 +44,21 @@ class Line(Graph):
 
     def line(self, serie_node, serie):
         view_values = map(self.view, serie.points)
-
         if self.show_dots:
-            dots = self.svg.node(serie_node['overlay'], class_="dots")
             for i, (x, y) in enumerate(view_values):
-                dot = self.svg.node(dots, class_='dot')
-                tag = '%d_%d' % (serie.index, i)
-                self.svg.node(dot, 'circle', cx=x, cy=y, r=2.5,
-                              id="active-%s" % tag,
-                              class_='reactive')
-                self.svg.node(dot, 'text', x=x, y=y,
-                              id="reactive-%s" % tag,
-                              class_='reactive-text'
-                ).text = self._get_value(serie.points, i)
+                dots = self.svg.node(serie_node['overlay'], class_="dots")
+                val = self._get_value(serie.points, i)
+                self.svg.node(dots, 'circle', cx=x, cy=y, r=2.5,
+                              class_='dot reactive tooltip-trigger')
+                self.svg.node(dots, 'desc', class_="value").text = val
+                self.svg.node(dots, 'desc', class_="x").text = str(x)
+                self.svg.node(dots, 'desc', class_="y").text = str(y)
+                if self.print_values:
+                    self.svg.node(
+                        serie_node['text_overlay'], 'text',
+                        x=x + self.value_font_size,
+                        y=y + self.value_font_size,
+                    ).text = val
 
         if self.stroke:
             if self.interpolate:
@@ -92,7 +94,7 @@ class Line(Graph):
         ) if not self.y_labels else map(int, self.y_labels)
 
         self._x_labels = self.x_labels and zip(self.x_labels, self._x_pos)
-        self._y_labels = zip(map(str, self._y_pos), self._y_pos)
+        self._y_labels = zip(map(self.format, self._y_pos), self._y_pos)
 
     def _plot(self):
         for serie in self.series:
